@@ -620,7 +620,9 @@ class PFBaseInterface:
       comres.iopt_exp = 6 # to export as csv
       path = dir + "\\" + file_name + ".csv"
       comres.f_name = path
-      comres.iopt_sep = 1 # to use the system seperator
+      comres.iopt_sep = 0 # Do NOT use system separator
+      comres.col_Sep = "," # Column separator
+      comres.dec_Sep = "." # Decimal separator
       comres.iopt_honly = 0 # to export data and not only the header
       comres.iopt_locn = 3 # column header includes path
       comres.ciopt_head = 1 # full variable name
@@ -776,7 +778,7 @@ class PFBaseInterface:
     if condition(obj_or_path):
       return obj_or_path
     else:
-      self.get_upstream_obj(obj_or_path, condition)
+      return self.get_upstream_obj(obj_or_path, condition)
 
   def get_path_between_objects(self, obj_high, obj_low):
     """Returns the path between two objects in the database.
